@@ -51,7 +51,7 @@ WebService::Gyazo::B::Image - gyazo.com image object
 
 =head1 VERSION
 
-version 0.0405
+version 0.0406
 
 =head1 SYNOPSIS
 
@@ -123,14 +123,15 @@ the same terms as the Perl 5 programming language system itself.
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=WebService-Gyazo-B or by email to
-bug-webservice-gyazo-b@rt.cpan.org.
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WebService-Gyazo-B> or by email
+to
+L<bug-webservice-gyazo-b@rt.cpan.org|mailto:bug-webservice-gyazo-b@rt.cpan.org>.
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -138,7 +139,7 @@ feature.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc WebService::Gyazo::B
+  perldoc WebService::Gyazo::B::Image
 
 =head2 Websites
 
@@ -153,15 +154,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/WebService-Gyazo-B>
-
-=item *
-
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/WebService-Gyazo-B>
+L<https://metacpan.org/release/WebService-Gyazo-B>
 
 =item *
 
@@ -173,30 +166,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=WebService-Gyazo-B>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/WebService-Gyazo-B>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/WebService-Gyazo-B>
-
-=item *
-
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/WebService-Gyazo-B>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -207,7 +176,7 @@ L<http://cpants.cpanauthors.org/dist/WebService-Gyazo-B>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/W/WebService-Gyazo-B>
 
